@@ -3,6 +3,7 @@
 
 BASH_BASE_SIZE=0x00000000
 CISCO_AC_TIMESTAMP=0x0000000000000000
+CISCO_AC_OBJNAME=1234567890123456789012345678901234567890123456789012345678901234
 # BASH_BASE_SIZE=0x00000000 is required for signing
 # CISCO_AC_TIMESTAMP is also required for signing
 # comment is after BASH_BASE_SIZE or else sign tool will find the comment
@@ -21,6 +22,7 @@ BINDIR=${INSTPREFIX}/bin
 LIBDIR=${INSTPREFIX}/lib
 PROFILEDIR=${INSTPREFIX}/profile
 SCRIPTDIR=${INSTPREFIX}/script
+HELPDIR=${INSTPREFIX}/help
 PLUGINDIR=${BINDIR}/plugins
 UNINST=${BINDIR}/vpn_uninstall.sh
 INSTALL=install
@@ -30,8 +32,9 @@ SYSVLEVELS="2 3 4 5"
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux-3.0.11042-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux-3.1.11004-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect Secure Mobility Client"
+FEEDBACK_DIR="${INSTPREFIX}/CustomerExperienceFeedback"
 
 echo "Installing ${CLIENTNAME}..."
 echo "Installing ${CLIENTNAME}..." > /tmp/${LOGFNAME}
@@ -48,7 +51,7 @@ fi
 if [ -f "license.txt" ]; then
     cat ./license.txt
     echo
-    echo -n "Do you accept the terms in the license agreement? [Y/n] "
+    echo -n "Do you accept the terms in the license agreement? [y/n] "
     read LICENSEAGREEMENT
     while : 
     do
@@ -108,16 +111,16 @@ if [ -x "${LEGACY_UNINST}" ]; then
 
   # local policy file
   if [ -f "${LEGACY_INSTPREFIX}/AnyConnectLocalPolicy.xml" ]; then
-    mv -f ${LEGACY_INSTPREFIX}/AnyConnectLocalPolicy.xml ${INSTPREFIX}/ 2>&1 >/dev/null
+    mv -f ${LEGACY_INSTPREFIX}/AnyConnectLocalPolicy.xml ${INSTPREFIX}/ >/dev/null 2>&1
   fi
 
   # global preferences
   if [ -f "${LEGACY_INSTPREFIX}/.anyconnect_global" ]; then
-    mv -f ${LEGACY_INSTPREFIX}/.anyconnect_global ${INSTPREFIX}/ 2>&1 >/dev/null
+    mv -f ${LEGACY_INSTPREFIX}/.anyconnect_global ${INSTPREFIX}/ >/dev/null 2>&1
   fi
 
   # logs
-  mv -f ${LEGACY_INSTPREFIX}/*.log ${INSTPREFIX}/ 2>&1 >/dev/null
+  mv -f ${LEGACY_INSTPREFIX}/*.log ${INSTPREFIX}/ >/dev/null 2>&1
 
   # VPN profiles
   if [ -d "${LEGACY_INSTPREFIX}/profile" ]; then
@@ -177,6 +180,8 @@ echo "Installing "${PROFILEDIR} >> /tmp/${LOGFNAME}
 ${INSTALL} -d ${PROFILEDIR} || exit 1
 echo "Installing "${SCRIPTDIR} >> /tmp/${LOGFNAME}
 ${INSTALL} -d ${SCRIPTDIR} || exit 1
+echo "Installing "${HELPDIR} >> /tmp/${LOGFNAME}
+${INSTALL} -d ${HELPDIR} || exit 1
 echo "Installing "${PLUGINDIR} >> /tmp/${LOGFNAME}
 ${INSTALL} -d ${PLUGINDIR} || exit 1
 echo "Installing "${ROOTCERTSTORE} >> /tmp/${LOGFNAME}
@@ -198,7 +203,7 @@ echo "Installing "${NEWTEMP}/anyconnect_uninstall.sh >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${NEWTEMP}/anyconnect_uninstall.sh ${BINDIR} || exit 1
 
 echo "Installing "${NEWTEMP}/vpnagentd >> /tmp/${LOGFNAME}
-${INSTALL} -o root -m 4755 ${NEWTEMP}/vpnagentd ${BINDIR} || exit 1
+${INSTALL} -o root -m 755 ${NEWTEMP}/vpnagentd ${BINDIR} || exit 1
 
 echo "Installing "${NEWTEMP}/libvpnagentutilities.so >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${NEWTEMP}/libvpnagentutilities.so ${LIBDIR} || exit 1
@@ -212,17 +217,17 @@ ${INSTALL} -o root -m 755 ${NEWTEMP}/libvpncommoncrypt.so ${LIBDIR} || exit 1
 echo "Installing "${NEWTEMP}/libvpnapi.so >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${NEWTEMP}/libvpnapi.so ${LIBDIR} || exit 1
 
-echo "Installing "${NEWTEMP}/libssl.so >> /tmp/${LOGFNAME}
-${INSTALL} -o root -m 755 ${NEWTEMP}/libssl.so ${LIBDIR} || exit 1
+echo "Installing "${NEWTEMP}/libacciscossl.so >> /tmp/${LOGFNAME}
+${INSTALL} -o root -m 755 ${NEWTEMP}/libacciscossl.so ${LIBDIR} || exit 1
 
-echo "Installing "${NEWTEMP}/libcrypto.so >> /tmp/${LOGFNAME}
-${INSTALL} -o root -m 755 ${NEWTEMP}/libcrypto.so ${LIBDIR} || exit 1
+echo "Installing "${NEWTEMP}/libacciscocrypto.so >> /tmp/${LOGFNAME}
+${INSTALL} -o root -m 755 ${NEWTEMP}/libacciscocrypto.so ${LIBDIR} || exit 1
 
-echo "Installing "${NEWTEMP}/libcurl.so.3.0.0 >> /tmp/${LOGFNAME}
-${INSTALL} -o root -m 755 ${NEWTEMP}/libcurl.so.3.0.0 ${LIBDIR} || exit 1
+echo "Installing "${NEWTEMP}/libaccurl.so.4.3.0 >> /tmp/${LOGFNAME}
+${INSTALL} -o root -m 755 ${NEWTEMP}/libaccurl.so.4.3.0 ${LIBDIR} || exit 1
 
-echo "Creating symlink "${NEWTEMP}/libcurl.so.3 >> /tmp/${LOGFNAME}
-ln -s ${LIBDIR}/libcurl.so.3.0.0 ${LIBDIR}/libcurl.so.3 || exit 1
+echo "Creating symlink "${NEWTEMP}/libaccurl.so.4 >> /tmp/${LOGFNAME}
+ln -s ${LIBDIR}/libaccurl.so.4.3.0 ${LIBDIR}/libaccurl.so.4 || exit 1
 
 if [ -f "${NEWTEMP}/libvpnipsec.so" ]; then
     echo "Installing "${NEWTEMP}/libvpnipsec.so >> /tmp/${LOGFNAME}
@@ -231,6 +236,13 @@ else
     echo "${NEWTEMP}/libvpnipsec.so does not exist. It will not be installed."
 fi 
 
+if [ -f "${NEWTEMP}/libacfeedback.so" ]; then
+    echo "Installing "${NEWTEMP}/libacfeedback.so >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 755 ${NEWTEMP}/libacfeedback.so ${PLUGINDIR} || exit 1
+else
+    echo "${NEWTEMP}/libacfeedback.so does not exist. It will not be installed."
+fi 
+
 if [ -f "${NEWTEMP}/vpnui" ]; then
     echo "Installing "${NEWTEMP}/vpnui >> /tmp/${LOGFNAME}
     ${INSTALL} -o root -m 755 ${NEWTEMP}/vpnui ${BINDIR} || exit 1
@@ -340,12 +352,19 @@ else
     echo "${NEWTEMP}/vpndownloader does not exist. It will not be installed."
 fi
 
+if [ -f "${NEWTEMP}/vpndownloader-cli" ]; then
+    # cached downloader (cli)
+    echo "Installing "${NEWTEMP}/vpndownloader-cli >> /tmp/${LOGFNAME}
+    ${INSTALL} -o root -m 755 ${NEWTEMP}/vpndownloader-cli ${BINDIR} || exit 1
+else
+    echo "${NEWTEMP}/vpndownloader-cli does not exist. It will not be installed."
+fi
+
 
 # Open source information
 echo "Installing "${NEWTEMP}/OpenSource.html >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 444 ${NEWTEMP}/OpenSource.html ${INSTPREFIX} || exit 1
 
-
 # Profile schema
 echo "Installing "${NEWTEMP}/AnyConnectProfile.xsd >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 444 ${NEWTEMP}/AnyConnectProfile.xsd ${PROFILEDIR} || exit 1
@@ -357,9 +376,18 @@ ${INSTALL} -o root -m 444 ${NEWTEMP}/AnyConnectLocalPolicy.xsd ${INSTPREFIX} ||
 # Also import the AnyConnectLocalPolicy.xml file (if present)
 # If failure occurs here then no big deal, don't exit with error code
 # only copy these files if tempdir is . which indicates predeploy
-if [ "${TEMPDIR}" = "." ]; then
-  PROFILE_IMPORT_DIR="../Profiles"
-  VPN_PROFILE_IMPORT_DIR="../Profiles/vpn"
+
+INSTALLER_FILE_DIR=$(dirname "$0")
+
+IS_PRE_DEPLOY=true
+
+if [ "${TEMPDIR}" != "." ]; then
+    IS_PRE_DEPLOY=false;
+fi
+
+if $IS_PRE_DEPLOY; then
+  PROFILE_IMPORT_DIR="${INSTALLER_FILE_DIR}/../Profiles"
+  VPN_PROFILE_IMPORT_DIR="${INSTALLER_FILE_DIR}/../Profiles/vpn"
 
   if [ -d ${PROFILE_IMPORT_DIR} ]; then
     find ${PROFILE_IMPORT_DIR} -maxdepth 1 -name "AnyConnectLocalPolicy.xml" -type f -exec ${INSTALL} -o root -m 644 {} ${INSTPREFIX} \;
@@ -370,6 +398,47 @@ if [ "${TEMPDIR}" = "." ]; then
   fi
 fi
 
+# Process transforms
+# API to get the value of the tag from the transforms file 
+# The Third argument will be used to check if the tag value needs to converted to lowercase 
+getProperty()
+{
+    FILE=${1}
+    TAG=${2}
+    TAG_FROM_FILE=$(grep ${TAG} "${FILE}" | sed "s/\(.*\)\(<${TAG}>\)\(.*\)\(<\/${TAG}>\)\(.*\)/\3/")
+    if [ "${3}" = "true" ]; then
+        TAG_FROM_FILE=`echo ${TAG_FROM_FILE} | tr '[:upper:]' '[:lower:]'`    
+    fi
+    echo $TAG_FROM_FILE;
+}
+
+DISABLE_FEEDBACK_TAG="DisableCustomerExperienceFeedback"
+
+if $IS_PRE_DEPLOY; then
+    if [ -d "${PROFILE_IMPORT_DIR}" ]; then
+        TRANSFORM_FILE="${PROFILE_IMPORT_DIR}/ACTransforms.xml"
+    fi
+else
+    TRANSFORM_FILE="${INSTALLER_FILE_DIR}/ACTransforms.xml"
+fi
+
+#get the tag values from the transform file  
+if [ -f "${TRANSFORM_FILE}" ] ; then
+    echo "Processing transform file in ${TRANSFORM_FILE}"
+    DISABLE_FEEDBACK=$(getProperty "${TRANSFORM_FILE}" ${DISABLE_FEEDBACK_TAG} "true" )
+fi
+
+# if disable phone home is specified, remove the phone home plugin and any data folder
+# note: this will remove the customer feedback profile if it was imported above
+FEEDBACK_PLUGIN="${PLUGINDIR}/libacfeedback.so"
+
+if [ "x${DISABLE_FEEDBACK}" = "xtrue" ] ; then
+    echo "Disabling Customer Experience Feedback plugin"
+    rm -f ${FEEDBACK_PLUGIN}
+    rm -rf ${FEEDBACK_DIR}
+fi
+
+
 # Attempt to install the init script in the proper place
 
 # Find out if we are using chkconfig
